@@ -3,6 +3,20 @@ from enum import Enum
 from typing import List, Optional
 
 
+class SemversionerException(Exception):
+    """
+    Base Exception
+    """
+    pass
+
+
+class MissingChangesetException(SemversionerException):
+    """
+    Missing changeset files
+    """
+    pass
+
+
 class ReleaseType(Enum):
     """
     Represents the type of release.
